==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/views/Extjs3/javascript/links/SelectLink.js <==
/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: SelectLink.js 8163 2011-09-27 08:02:33Z wsmits $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
GO.form.SelectLink = function(config){
	
	config = config || {};
	
	config.store = new GO.data.JsonStore({				
		url: GO.url('search/store'),
		fields:['model_id','model_name','name_and_type', 'model_name_and_id'],
		remoteSort: true				
	});

	config.forceSelection=true;
	config.displayField='name_and_type';
	config.valueField='model_name_and_id',
	config.hiddenName='link';
	config.triggerAction='all';
	config.width=400;
	config.selectOnFocus=false;
	config.fieldLabel=GO.lang.cmdLink;
	config.pageSize=20;//parseInt(GO.settings['max_rows_list']);
	GO.form.SelectLink.superclass.constructor.call(this, config);
	
}

Ext.extend(GO.form.SelectLink, GO.form.ComboBoxReset,{
	onTriggerClick : function(){

		if(!GO.selectLinkDialog){
			GO.selectLinkDialog = new GO.dialog.LinksDialog({
				singleSelect:true,
				selectLinkField:this,
				linkItems : function()	{
					var selectionModel = this.grid.searchGrid.getSelectionModel();
					var record = selectionModel.getSelected();

					this.selectLinkField.setValue(record.get('model_name_and_id'));
					this.selectLinkField.setRemoteText(record.get('name_and_type'));
					this.hide();
				}
			});
		}
		GO.selectLinkDialog.show();
		
	}
});

==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/views/Extjs3/javascript/links/SelectLink.js <==
/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: SelectLink.js 13045 2012-12-17 15:31:25Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
GO.form.SelectLink = function(config){
	
	config = config || {};
	
	config.store = new GO.data.JsonStore({				
		url: GO.url('search/store'),
		fields:['model_id','model_name','name_and_type', 'model_name_and_id'],
		remoteSort: true,
		baseParams:{
			start:0,
			limit:20,
			dont_calculate_total:1
		}
	});

	config.forceSelection=true;
	config.displayField='name_and_type';
	config.valueField='model_name_and_id',
	config.hiddenName='link';
	config.triggerAction='all';
	config.width=400;
	config.selectOnFocus=false;
	config.fieldLabel=GO.lang.cmdLink;
//	config.pageSize=20;//parseInt(GO.settings['max_rows_list']);
	GO.form.SelectLink.superclass.constructor.call(this, config);
	
}

Ext.extend(GO.form.SelectLink, GO.form.ComboBoxReset,{
	onTriggerClick : function(){

		if(!GO.selectLinkDialog){
			GO.selectLinkDialog = new GO.dialog.LinksDialog({
				singleSelect:true,
				selectLinkField:this,
				linkItems : function()	{
					var selectionModel = this.grid.searchGrid.getSelectionModel();
					var record = selectionModel.getSelected();

					this.selectLinkField.setValue(record.get('model_name_and_id'));
					this.selectLinkField.setRemoteText(record.get('name_and_type'));
					this.hide();
				}
			});
		}
		GO.selectLinkDialog.show();
		
	}
});
